@@ -4,7 +4,7 @@ from typing import Union, List
 from datetime import time as DTime
 
 # ------------------------------------------------STR_TO----------------------------------------------------------------
-from web_foundation.workers.web.erorrs.application import InconsistencyError
+from wf_old.workers.web.erorrs.application import InconsistencyError
 
 
 def str_to_list(string: str) -> Union[List[str], None]:
